@@ -16,7 +16,7 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '2.09';
+our $VERSION = '2.11';
 
 my $settings = undef;
 
@@ -185,6 +185,18 @@ database, e.g.:
             host: localhost
             sid: ABC12
 
+If you have any further connection parameters that need to be appended
+to the dsn, you can put them in as a hash called dsn_extra. For
+example, if you're running mysql on a non-standard socket, you could
+have
+
+   plugins:
+       Database:
+           driver: mysql
+           host: localhost
+           dsn_extra:
+               mysql_socket: /tmp/mysql_staging.sock
+
 
 =head2 DEFINING MULTIPLE CONNECTIONS
 
@@ -429,7 +441,7 @@ You can find the author on IRC in the channel C<#dancer> on <irc.perl.org>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-12 David Precious.
+Copyright 2010-2015 David Precious.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
